@@ -868,7 +868,7 @@ static inline CPInfo * cpinfo_malloc(void)
 	cpinfo->s_para = DEFAULT;
 	cpinfo->hash_check = false;
 	cpinfo->file_test = false;
-	cpinfo->verify_md5 = NULL;
+	cpinfo->src_md5 = NULL;
 	cpinfo->src_size = 0;
 	cpinfo->dst_size = 0;
 
