@@ -223,8 +223,14 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 		filesystem_check = true;
 	}
 
-	cpinfo->src_size = 0;
-	cpinfo->dst_size = 0;
+	if(cpinfo->copy_mode == SAME)
+	{
+		if(strcmp(cpinfo->src, cpinfo->dst) == 0)
+		{
+			fprintf(stderr, "`%s' と `%s' は同じファイルです\n", cpinfo->src, cpinfo->dst);
+			return;
+		}
+	}
 
 	errno = 0;
 	if((isrc = open(cpinfo->src, O_RDONLY | O_NOATIME | O_NOFOLLOW)) == -1)
