@@ -1,6 +1,5 @@
 #include "analyze_argument.h"
 #include "check_target.h"
-#include "compare_hash.h"
 #include "get_drive_list.h"
 #include "get_settings_dir.h"
 #include "help.h"
@@ -98,9 +97,9 @@ int main(int argc, char **argv)
 	if(oparg->M == MOVE)
 	{
 		if(
-			((oparg->CHECK == NOT) && ((cpdd->mk_file_count > 0) || (cpdd->mk_link_count > 0) || (cpdd->mk_dir_count > 0)))
+			((oparg->CHECK == NOT) && ((cpdd->mk_file_count > 0) || (cpdd->mk_link_count > 0) || (cpdd->dir_count > 0)))
 			||
-			((oparg->CHECK != NOT) && ((cpdd->mk_link_count > 0) || (cpdd->mk_dir_count > 0)))
+			((oparg->CHECK != NOT) && ((cpdd->mk_link_count > 0) || (cpdd->dir_count > 0)))
 		)
 		{
 			puts("コピー元の削除を開始します...");
@@ -163,28 +162,6 @@ int main(int argc, char **argv)
 	cpinfo->s_para = UNLINK;\
 }
 
-/*******************************************************************************
-*******************************************************************************/
-#define HASH_CHECK \
-{\
-	if(cpinfo->d_para == WRITE)\
-	{\
-		compare_hash(oparg, sdir, cpinfo, cpdd);\
-\
-		if((oparg->M == MOVE) && (cpinfo->hash_check == true))\
-		{\
-			FILE_REMOVE\
-		}\
-\
-	}\
-	else if(cpinfo->d_para != SKIP)\
-	{\
-		fprintf(stderr, "ファイルの書き込みに失敗しているため、コンペアをスキップします\n");\
-		fprintf(stderr, "src : %s\n", cpinfo->src);\
-		fprintf(stderr, "dst : %s\n", cpinfo->dst);\
-	}\
-}
-
 /*******************************************************************************
 *******************************************************************************/
 static inline void do_compare_verify_two(const OPArg *oparg, const VList *file_list, const SDir *sdir, CPDD *cpdd)
@@ -203,35 +180,8 @@ static inline void do_compare_verify_two(const OPArg *oparg, const VList *file_l
 		{
 			switch(oparg->CHECK)
 			{
-			case ONE:
-				HASH_CHECK
-				break;
-
-			case FIVE:
-				HASH_CHECK
-				break;
-
 			case V_FIVE:
-				if(cpinfo->verify_md5 == NULL)
-				{
-					/*
-					 * コピーを実行していればsrc_sizeは0以上に、
-					 * していなければ0になっている。
-					*/
-					if(cpinfo->src_size > 0)
-					{
-						fprintf(stderr, "ベリファイをスキップします\n");
-						fprintf(stderr, "dst : %s\n", cpinfo->dst);
-					}
-					else if(cpinfo->src_size < 0)
-					{
-						/* ここが実行されることは無い */
-						fprintf(stderr, "コピー元のファイサイズが不正です\n");
-						fprintf(stderr, "ベリファイをスキップします\n");
-						fprintf(stderr, "dst : %s\n", cpinfo->dst);
-					}
-				}
-				else
+				if((cpinfo->src_md5 != NULL) && (cpinfo->dst_size > 0) && (cpinfo->d_para == WRITE))
 				{
 					verify_hash(oparg, sdir, cpinfo, cpdd);
 
@@ -243,7 +193,7 @@ static inline void do_compare_verify_two(const OPArg *oparg, const VList *file_l
 				break;
 
 			default:
-				fprintf(stderr, "コンペアオプションが不正です");
+				fprintf(stderr, "ハッシュチェックオプションが不正です");
 				break;
 			}
 		}
