@@ -45,7 +45,7 @@ typedef struct copy_infomation
 	SPT s_para;
 	_Bool hash_check;
 	_Bool file_test;
-	char *verify_md5;
+	char *src_md5;
 	off_t src_size;
 	off_t dst_size;
 } CPInfo;
