@@ -3,6 +3,7 @@
 #include "print_error.h" // inline
 #include "struct_CPInfo.h"
 #include "struct_OPArg.h"
+#include "verify_md5sum.h"
 #include "write_log_hash_check.h" // inline
 
 #include "md5.h"
@@ -36,7 +37,7 @@ static _Bool read_finish;
 
 #define UNLINK_MISS_FILE \
 	print_error("NODATA", __FILE__, __LINE__, cpdd);\
-	write_log_hash_check(cpinfo, cpinfo->verify_md5, hex_output, sdir, cpdd, false);\
+	write_log_hash_check(cpinfo, cpinfo->src_md5, hex_output, sdir, cpdd, false);\
 	cpinfo->d_para = DELETE;\
 \
 	errno = 0;\
@@ -51,6 +52,7 @@ static _Bool read_finish;
 
 /* 関数プロトタイプ */
 void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd);
+static void o_direct(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd);
 static void * read_func(void *dummy);
 static void * append_func(void *dummy);
 
@@ -58,7 +60,6 @@ static void * append_func(void *dummy);
 *******************************************************************************/
 void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd)
 {
-	static _Bool get_memory = false;
 	fd = 0;
 	buffer_size_local = oparg->buffer_size / 2;
 	read_size[0] = 0;
@@ -69,14 +70,14 @@ void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpd
 	read_err = false;
 	read_finish = false;
 
-	_Bool open_flag = false;
-
 	if(psize == 0)
 	{
 		psize = sysconf(_SC_PAGESIZE);
 	}
 
+	_Bool open_flag;
 	errno = 0;
+
 	if((fd = open(cpinfo->dst, O_NOATIME | O_NOFOLLOW | O_DIRECT | O_RDONLY)) == -1)
 	{
 		switch(errno)
@@ -84,7 +85,7 @@ void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpd
 		case EPERM:
 			if((fd = open(cpinfo->dst, O_NOFOLLOW | O_DIRECT | O_RDONLY)) == -1)
 			{
-				print_error("open", __FILE__, __LINE__, cpdd);
+				open_flag = false;
 			}
 			else
 			{
@@ -93,7 +94,7 @@ void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpd
 			break;
 
 		default:
-			print_error("open", __FILE__, __LINE__, cpdd);
+			open_flag = false;
 			break;
 		}
 	}
@@ -104,108 +105,11 @@ void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpd
 
 	if(open_flag == true)
 	{
-		if((buf[0] == NULL) &&(buf[1] == NULL))
-		{
-			if((posix_memalign((void **)&buf[0], psize, buffer_size_local) != 0) || (posix_memalign((void **)&buf[1], psize, buffer_size_local) != 0))
-			{
-				fprintf(stderr, "ベリファイに失敗しました\n");
-				fprintf(stderr, "%s\n", cpinfo->dst);
-				print_error("posix_memalign", __FILE__, __LINE__, cpdd);
-				write_log_hash_check(cpinfo, cpinfo->verify_md5, "NULL", sdir, cpdd, false);
-			}
-			else
-			{
-				get_memory = true;
-			}
-		}
-
-		switch(get_memory)
-		{
-		case true:
-			md5_init(&state);
-
-			r_number = 0;
-			a_number = 1;
-			pthread_t t1;
-			pthread_t t2;
-
-			pthread_create(&t1, NULL, read_func, (void *)&r_number);
-			pthread_join(t1, NULL);
-
-			int swap;
-
-			for(;;)
-			{
-				swap = r_number;
-				r_number = a_number;
-				a_number = swap;
-
-				pthread_create(&t1, NULL, read_func, (void *)&r_number);
-				pthread_create(&t2, NULL, append_func, (void *)&a_number);
-
-				pthread_join(t1, NULL);
-				pthread_join(t2, NULL);
-
-				if((read_finish == true) || (read_err == true))
-				{
-					break;
-				}
-			}
-
-			md5_finish(&state, digest);
-
-			static char hex_output[(16 * 2) + 1];
-			hex_output[0] = '\0';
-
-			for(int di = 0; di < 16; ++di)
-			{
-				sprintf(hex_output + di * 2, "%02x", digest[di]);
-			}
-
-			if(strcmp(cpinfo->verify_md5, hex_output) == 0)
-			{
-				cpinfo->hash_check = true;
-
-				if(oparg->V == VERBOS)
-				{
-					printf("%s : %s\n", cpinfo->verify_md5, cpinfo->src);
-					printf("%s : %s\n", hex_output, cpinfo->dst);
-					fflush(stdout);
-				}
-
-				if(oparg->L == LOG)
-				{
-					write_log_hash_check(cpinfo, cpinfo->verify_md5, hex_output, sdir, cpdd, true);
-				}
-			}
-			else if(cpinfo->src_size > total)
-			{
-				fprintf(stderr, "ファイルの読み込みに失敗しました、%sを削除します\n", cpinfo->dst);
-				UNLINK_MISS_FILE
-			}
-			else
-			{
-				fprintf(stderr, "ハッシュ値が一致しませんでした、%sを削除します\n", cpinfo->dst);
-				UNLINK_MISS_FILE
-			}
-			break;
-
-		case false:
-			fprintf(stderr, "ベリファイ出来ません\n");
-			fprintf(stderr, "メモリの確保に失敗しました\n");
-			print_error("NODATA", __FILE__, __LINE__, cpdd);
-			write_log_hash_check(cpinfo, cpinfo->verify_md5, "NULL", sdir, cpdd, false);
-			cpinfo->d_para = INITIAL;
-			break;
-		}
+		o_direct(oparg, sdir, cpinfo, cpdd);
 	}
 	else
 	{
-		fprintf(stderr, "ベリファイに失敗しました\n");
-		fprintf(stderr, "%sをオープン出来ません\n", cpinfo->dst);
-		print_error("NODATA", __FILE__, __LINE__, cpdd);
-		write_log_hash_check(cpinfo, cpinfo->verify_md5, "NULL", sdir, cpdd, false);
-		cpinfo->d_para = INITIAL;
+		verify_md5sum(oparg, sdir, cpinfo, cpdd);
 	}
 
 	if(open_flag == true)
@@ -221,12 +125,113 @@ void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpd
 */
 }
 
+/*******************************************************************************
+*******************************************************************************/
+static void o_direct(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd)
+{
+	static _Bool get_memory = false;
+
+	if((buf[0] == NULL) && (buf[1] == NULL))
+	{
+		if((posix_memalign((void **)&buf[0], psize, buffer_size_local) != 0) || (posix_memalign((void **)&buf[1], psize, buffer_size_local) != 0))
+		{
+			fprintf(stderr, "ベリファイに失敗しました\n");
+			fprintf(stderr, "%s\n", cpinfo->dst);
+			print_error("posix_memalign", __FILE__, __LINE__, cpdd);
+			write_log_hash_check(cpinfo, cpinfo->src_md5, "NULL", sdir, cpdd, false);
+		}
+		else
+		{
+			get_memory = true;
+		}
+	}
+
+	switch(get_memory)
+	{
+	case true:
+		md5_init(&state);
+
+		r_number = 0;
+		a_number = 1;
+		pthread_t t1;
+		pthread_t t2;
+
+		pthread_create(&t1, NULL, read_func, (void *)&r_number);
+		pthread_join(t1, NULL);
+
+		int swap;
+
+		for(;;)
+		{
+			swap = r_number;
+			r_number = a_number;
+			a_number = swap;
+
+			pthread_create(&t1, NULL, read_func, (void *)&r_number);
+			pthread_create(&t2, NULL, append_func, (void *)&a_number);
+
+			pthread_join(t1, NULL);
+			pthread_join(t2, NULL);
+
+			if((read_finish == true) || (read_err == true))
+			{
+				break;
+			}
+		}
+
+		md5_finish(&state, digest);
+
+		static char hex_output[(16 * 2) + 1];
+		hex_output[0] = '\0';
+
+		for(int di = 0; di < 16; ++di)
+		{
+			sprintf(hex_output + di * 2, "%02x", digest[di]);
+		}
+
+		if(strcmp(cpinfo->src_md5, hex_output) == 0)
+		{
+			cpinfo->hash_check = true;
+
+			if(oparg->V == VERBOS)
+			{
+				printf("%s : %s\n", cpinfo->src_md5, cpinfo->src);
+				printf("%s : %s\n", hex_output, cpinfo->dst);
+				fflush(stdout);
+			}
+
+			if(oparg->L == LOG)
+			{
+				write_log_hash_check(cpinfo, cpinfo->src_md5, hex_output, sdir, cpdd, true);
+			}
+		}
+		else if(cpinfo->src_size > total)
+		{
+			fprintf(stderr, "ファイルの読み込みに失敗しました、%sを削除します\n", cpinfo->dst);
+			UNLINK_MISS_FILE
+		}
+		else
+		{
+			fprintf(stderr, "ハッシュ値が一致しませんでした、%sを削除します\n", cpinfo->dst);
+			UNLINK_MISS_FILE
+		}
+		break;
+
+	case false:
+		fprintf(stderr, "ベリファイ出来ません\n");
+		fprintf(stderr, "メモリの確保に失敗しました\n");
+		print_error("NODATA", __FILE__, __LINE__, cpdd);
+		write_log_hash_check(cpinfo, cpinfo->src_md5, "NULL", sdir, cpdd, false);
+		cpinfo->d_para = INITIAL;
+		break;
+	}
+}
+
 /*******************************************************************************
 *******************************************************************************/
 static void * read_func(void *dummy)
 {
-	static int i;
-	i = r_number;
+	int i = r_number;
 
 	/* 
 	 * O_DIRECTを使用するとアライメントの調整などが面倒なので、
@@ -255,8 +260,7 @@ static void * read_func(void *dummy)
 *******************************************************************************/
 static void * append_func(void *dummy)
 {
-	static int i;
-	i = a_number;
+	int i = a_number;
 
 	md5_append(&state, buf[i], read_size[i]);
 
