@@ -16,7 +16,7 @@ static inline void * xmalloc(const size_t size)
 
 	if(!p)
 	{
-		perror("xmalloc");
+		perror("malloc");
 		exit(EXIT_FAILURE);
 	}
 
